@@ -5,6 +5,7 @@ import pandas as pd
 from house_prices_regression_model import __version__ as VERSION
 from house_prices_regression_model.processing.data_manager import load_pipeline
 from house_prices_regression_model.config.core import load_config_file, SETTINGS_PATH
+from house_prices_regression_model.processing.data_validation import validate_inputs
 
 # Config files
 config = load_config_file(SETTINGS_PATH)
@@ -16,7 +17,14 @@ cb_pipe = load_pipeline(file_name=pipeline_file_name)
 #Function
 def make_prediction(*,input_data: t.Union[pd.DataFrame, dict],) -> list:
     """Make a prediction using a saved model pipeline."""
-    data = pd.DataFrame(input_data)
-    log_predictions = cb_pipe.predict(data)
-    predictions = [np.exp(pred) for pred in log_predictions]
-    return predictions
+    df = pd.DataFrame(input_data)
+    validated_df, error_dict = validate_inputs(input_data=df)
+    errors_list = list(error_dict.values())
+    results = {'model_output': None}
+    if error_dict == {}:
+        log_predictions = cb_pipe.predict(validated_df)
+        predictions = [np.exp(pred) for pred in log_predictions]
+        results['model_output'] = predictions
+    else:
+        results['model_output'] = 'Errors making prediction:' + ' '.join(map(str, errors_list))
+    return results
